pub(crate) struct RunnableDocTest<'a> {
full_test_code: String,
full_test_line_offset: usize,
test_opts: &'a IndividualTestOptions,
global_opts: &'a GlobalTestOptions,
langstr: LangString,
line: usize,
edition: Edition,
no_run: bool,
merged_test_runner_code: Option<String>,
}Expand description
Information needed for running a bundle of doctests.
This data structure contains the “full” test code, including the wrappers
(if multiple doctests are merged), main function,
and everything needed to calculate the compiler’s command-line arguments.
The # prefix on boring lines has also been stripped.
Fields
full_test_code: StringIn a merged test, this is the code for the “bundle” that contains the actual doctests. In a standalone test this is just the regular test code.
full_test_line_offset: usizetest_opts: &'a IndividualTestOptionsglobal_opts: &'a GlobalTestOptionslangstr: LangStringline: usizeedition: Editionno_run: boolmerged_test_runner_code: Option<String>If Some, this is a merged test and the string is the code for the “runner” that contains
the test harness to invoke the doctests.
Implementations
Sourceimpl RunnableDocTest<'_>
impl RunnableDocTest<'_>
fn path_for_merged_doctest_bundle(&self) -> PathBuf
fn path_for_merged_doctest_runner(&self) -> PathBuf
fn is_multiple_tests(&self) -> bool